@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptohash-conduit
 version: 0.1.1
-id: cryptohash-conduit-0.1.1-6b607828fd72a263de0a99a243d6077b
-key: crypt_77uE8Q2g2rm1VacIZxOpEj
+id: cryptohash-conduit-0.1.1-9cd42855330eec21f69d5ac4f36d7158
+key: crypt_20eICGlNvlOEnTLJBjRFbD
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -22,13 +22,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
-hs-libraries: HScryptohash-conduit-0.1.1-77uE8Q2g2rm1VacIZxOpEj
+hs-libraries: HScryptohash-conduit-0.1.1-20eICGlNvlOEnTLJBjRFbD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
-    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
+    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
